@@ -1,4 +1,8 @@
 import replitdb
+import sys
+import os
+def main():
+  commandHandler(sys.argv,os.environ['REPLIT_DB_URL'])
 def commandHandler(args,url):
   client = replitdb.Client(url)
   command = args[0].lower()
